.. Copyright (C) 2018 Branko Majic

   This file is part of Gimmecert documentation.

   This work is licensed under the Creative Commons Attribution-ShareAlike 3.0
   Unported License. To view a copy of this license, visit
   http://creativecommons.org/licenses/by-sa/3.0/ or send a letter to Creative
   Commons, 444 Castro Street, Suite 900, Mountain View, California, 94041, USA.


Gimmecert documentation
=======================

Gimmecert is a simple CLI tool for quickly issuing X.509 server and
client certificates using locally-generated CA hierarchy with minimal
hassle.


Contents
--------

.. toctree::
   :maxdepth: 2

   about
   installation
   usage
   development
   releasenotes


Indices and tables
------------------

- :ref:`genindex`
- :ref:`modindex`
- :ref:`search`
